Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(21)

Unified Diff: tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py

Issue 2296043003: Rename Lo-Fi previews to lite pages (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@newLoFiInfoBarAddTests
Patch Set: tbansal comments Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
diff --git a/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py b/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
index d3c449201da80ac9c4bbd392d3e7e3195d29b5c5..819af518894cbaeba2e06cd45739f791bacb0ff5 100644
--- a/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
+++ b/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
@@ -415,24 +415,24 @@ class ChromeProxyCacheProxyDisabled(ChromeProxyValidation):
tab.ExecuteJavaScript('window.location.reload()')
util.WaitFor(tab.HasReachedQuiescence, 3)
-class ChromeProxyLoFiPreview(ChromeProxyValidation):
- """Correctness measurement for Lo-Fi preview in Chrome-Proxy header."""
+class ChromeProxyLitePage(ChromeProxyValidation):
+ """Correctness measurement for lite pages in the Chrome-Proxy header."""
def __init__(self):
- super(ChromeProxyLoFiPreview, self).__init__(
+ super(ChromeProxyLitePage, self).__init__(
restart_after_each_page=True,
metrics=metrics.ChromeProxyMetric())
def CustomizeBrowserOptions(self, options):
- super(ChromeProxyLoFiPreview, self).CustomizeBrowserOptions(options)
+ super(ChromeProxyLitePage, self).CustomizeBrowserOptions(options)
options.AppendExtraBrowserArgs(
'--data-reduction-proxy-lo-fi=always-on')
options.AppendExtraBrowserArgs(
- '--enable-data-reduction-proxy-lo-fi-preview')
+ '--enable-data-reduction-proxy-lite-page')
options.AppendExtraBrowserArgs('--disable-quic')
def AddResults(self, tab, results):
- self._metrics.AddResultsForLoFiPreview(tab, results)
+ self._metrics.AddResultsForLitePage(tab, results)
class ChromeProxyExpDirective(ChromeProxyValidation):
"""Correctness measurement for experiment directives in Chrome-Proxy header.

Powered by Google App Engine
This is Rietveld 408576698